@@ -1,7 +1,7 @@
 package Monitoring::Icinga2::Client::Simple;
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_06'; # TRIAL
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_08'; # TRIAL
 
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100006';use strict;
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100008';use strict;
 use warnings;
 use 5.010_001;
 use Monitoring::Icinga2::Client::REST 2;
@@ -15,9 +15,9 @@ sub new {
     croak( "only hash-style args are supported" ) if @_ % 2;
     my %args = @_;
     # uncoverable condition false
-    my $hostname = delete $args{hostname} // croak( "`hostname' arg is required" );
+    my $server = delete $args{server} // croak( "`server' arg is required" );
     my $ua = delete $args{useragent};
-    my $self = $class->SUPER::new( $hostname, %args );
+    my $self = $class->SUPER::new( $server, %args );
     if( defined $ua ) {
         # This is a hack as I don't maintain the superclass. However, I wrote its
         # constructor and we'll check whether it has changed so it should be fine.
@@ -25,6 +25,9 @@ sub new {
         defined $self->{ua} or croak( 'Monitoring::Icinga2::Client::REST seems to have changed internals; '. 'passing `useragent\' does not work. Please notify mbethke@cpan.org');
         $ua->default_header( 'Accept' => 'application/json' );
         $self->{ua} = $ua;
+        # uncoverable condition false
+        # uncoverable branch right
+        $self->{_mics_author} = getlogin || getpwuid($<);
     }
     return $self;
 }
@@ -33,7 +36,7 @@ sub schedule_downtime {
     my ($self, %args) = @_;
     _checkargs(\%args, qw/ start_time end_time comment host /);
     # uncoverable condition true
-    $args{author} //= getlogin;
+    $args{author} //= $self->{_mics_author};
 
     if( $args{service} and not $args{services} ) {
         return [ $self->_schedule_downtime_type( 'Service', \%args) ];
@@ -110,7 +113,8 @@ sub send_custom_notification {
             filter => "$obj_type.name==\"$args{$obj_type}\"",
             comment => $args{comment},
             # uncoverable condition false
-            author => $args{author} // getlogin,
+            # uncoverable branch right
+            author => $args{author} // $self->{_mics_author},
         }
     );
 }
@@ -282,7 +286,31 @@ Monitoring::Icinga2::Client::Simple
 
 =head1 VERSION
 
-version 0.001000_06
+version 0.001000_08
+
+=head1 SYNOPSIS
+
+    use Monitoring::Icinga2::Client::Simple;
+    use Data::Dumper;
+
+    # Instantiate an Icinga2 API client
+    my $ia = Monitoring::Icinga2::Client::Simple->new( server => 'monitoring.mycompany.org' );
+
+    # Disable notifications application-wide
+    $ia->set_global_notifications( 0 );
+
+    # Schedule an hour of downtime for web-1 and all of its services
+    $ia->schedule_downtime(
+        host => 'web-1',
+        services => 1;
+        start_time => scalar(time),
+        end_time => time + 3600,
+        fixed => 1,
+        comment => 'System maintenance',
+    );
+
+    # Print a summary of everything Icinga knows about web-1
+    print Dumper( $ia->query_host( host => 'web-1' ) );
 
 =head1 DESCRIPTION
 
@@ -301,9 +329,7 @@ Enabling and disabling notifications for individual objects
 
 =item *
 
-Setting and getting global flags like those found under "Monitoring
-
-Health" -- notifications, active checks etc.
+Setting and getting global flags like those found under "Monitoring Health" -- notifications, active checks etc.
 
 =item *
 
@@ -321,11 +347,7 @@ still allowing to make more specialized API calls yourself.
 =head2 new
 
     $ia = Monitoring::Icinga2::Client::Simple->new( agent => $ua );
-
-    $ia = Monitoring::Icinga2::Client::Simple->new(
-        hostname => 'monitoring.mycompany.org',
-        path => 'icinga2',
-    );
+    $ia = Monitoring::Icinga2::Client::Simple->new( hostname => 'monitoring.mycompany.org' );
 
 The constructor supports almost the same arguments as the one in
 L<Monitoring::Icinga2::Client::REST>. The differences are:
@@ -338,11 +360,11 @@ Only the extensible hash style arguments are supported
 
 =item *
 
-The C<$hostname> parameter is not a positional one but passed hash-style, too, under the key C<hostname>.
+The C<$hostname> parameter is not a positional one but passed hash-style, too, under the key C<server>.
 
 =item *
 
-An additional key C<useragent> allows to in your own L<LWP::UserAgent> object; this enables more complicated configurations like using TLS client certificates that would otherwise make the number of arguments explode.
+An additional key C<useragent> allows to pass in your own L<LWP::UserAgent> object; this enables more complicated configurations like using TLS client certificates that would otherwise make the number of arguments explode.
 
 =back
 
@@ -398,7 +420,7 @@ C<services>: set to a true value to set downtimes on all of a host's services. D
 
 =item *
 
-C<author>: will use L<getlogin> if unset
+C<author>: will use L<getlogin()|perlfunc/getlogin> (or L<getpwuid|perlfunc/getpwuid> where that's unavailable) if unset
 
 =item *
 
@@ -433,7 +455,7 @@ C<status>: human-readable status message
 
     $ia->remove_downtime( name => "web-1!NTP!49747048-f8d9-4ecc-95a4-86aa4c1011a9" );
     $ia->remove_downtime( host => "web-1", service => 'NTP' );
-    $ia->remove_downtime( host => "web-1" services => 1 );
+    $ia->remove_downtime( host => "web-1", services => 1 );
 
 Remove a downtime by name or host/service name
 
@@ -474,7 +496,7 @@ argument to also delete all of this host's service downtimes.
 
 Query all information Icinga2 has on a certain host. The result is a hashref,
 currently containing a single key C<attrs>. If the host is not found, C<undef>
-is eturned.
+is returned.
 
 The only mandatory argument is C<host>.
 
@@ -563,11 +585,11 @@ C<node_name>: string
 
 =item *
 
-C<pid> integer
+C<pid>: integer
 
 =item *
 
-C<program_start> floatingpoint timestamp
+C<program_start>: floatingpoint timestamp
 
 =item *
 
